@@ -24,6 +24,10 @@
 #include <ctype.h>
 #include "dlispparser.h"
 
+/** @file dlispfreememory.h
+    @brief memory freeing routine
+ */
+
 /**
    Free memory allocated for the lisp data structure 
  */
